@@ -13,6 +13,16 @@ class GetMediaShowItemView(BrowserView):
     """ Class that extracts relevant information for the slideshow
     """
     def getJSON(self):
+        if hasattr(self.request, 'presentation'):
+            presentation = self.request['presentation']
+        else:
+            presentation = "false"
+        
+        presentationMode = False
+        
+        if presentation.find("true") != -1:
+            presentationMode = True
+        
         callback = hasattr(self.request, 'callback') and 'json' + self.request['callback'] or None
         
         media = self.getMediaURL()
@@ -25,17 +35,16 @@ class GetMediaShowItemView(BrowserView):
         else:
             title = ""
         
-        if hasattr(self, "description"):
+        if presentationMode and hasattr(self.context, 'aq_explicit') and hasattr(self.context.aq_explicit, "getText"):
+                description = self.context.getText()
+        elif hasattr(self, "description"):
             description = self.context.description
         elif hasattr(self.context, "Description"):
             description = self.context.Description()
         else:
             description = ""
-           
-        type = self.context.portal_type
             
-        title = self.sanitizeStringForJson(title)    
-        description = self.sanitizeStringForJson(description)
+        type = self.context.portal_type
         
         #python to json encoding
         jsonStr = json.dumps({"title": title, "description":description, "type": type, "media": {"url": media, "type": mediaType}})
@@ -106,7 +115,7 @@ class MediaShowListingView(BrowserView):
     """ Class that extracts relevant information for the slideshow
     """
     
-    def getJSON(self):
+    def getJSON(self):    
         callback = hasattr(self.request, 'callback') and 'json' + self.request['callback'] or None
         jsonStr = ""
         
